@@ -50,6 +50,12 @@ class QueryApi(object):
             else:
                 query_params['limit'] = 500
 
+        if 'offset' in params:
+            if params['offset'] is not None:
+                query_params['offset'] = params['offset']
+            else:
+                query_params['offset'] = 0
+
         if 'response_type' in params:
             if params['response_type'] is not None:
                 if hasattr(netsuite.swagger_client.models, params['response_type']):
